
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.8.1',
    'branch_nick': '(no',
    'revision_id': '695c65cf6f0677207eda8d780394fb8df9df4f2a',
    'revno': 4473
}
